@@ -193,6 +193,14 @@ void bcp_implementation::add_file(const fs::path& p)
    //
 static const std::pair<fs::path, fs::path>
    specials[] = {
+      std::pair<fs::path, fs::path>("boost/atomic/capabilities.hpp", "boost/atomic/detail"),
+      std::pair<fs::path, fs::path>("boost/chrono/chrono.hpp", "libs/chrono/src"),
+      std::pair<fs::path, fs::path>("boost/chrono/chrono.hpp", "libs/chrono/build"),
+      std::pair<fs::path, fs::path>("boost/cerrno.hpp", "libs/system/build"),
+      std::pair<fs::path, fs::path>("boost/cerrno.hpp", "libs/system/src"),
+      std::pair<fs::path, fs::path>("libs/thread/build", "boost/system"),
+      std::pair<fs::path, fs::path>("libs/thread/build", "boost/cerrno.hpp"),
+      std::pair<fs::path, fs::path>("libs/thread/build", "boost/chrono"),
       std::pair<fs::path, fs::path>("boost/filesystem/convenience.hpp", "boost/filesystem.hpp"),
       std::pair<fs::path, fs::path>("boost/filesystem/exception.hpp", "boost/filesystem.hpp"),
       std::pair<fs::path, fs::path>("boost/filesystem/fstream.hpp", "boost/filesystem.hpp"),
@@ -202,22 +210,16 @@ static const std::pair<fs::path, fs::path>
       std::pair<fs::path, fs::path>("boost/filesystem.hpp", "libs/filesystem/v2"),
       std::pair<fs::path, fs::path>("boost/filesystem.hpp", "libs/filesystem/v3"),
       std::pair<fs::path, fs::path>("boost/config.hpp", "boost/config"),
-      std::pair<fs::path, fs::path>("tools/build/allyourbase.jam", "Jamrules"),
-      std::pair<fs::path, fs::path>("tools/build/allyourbase.jam", "project-root.jam"),
-      std::pair<fs::path, fs::path>("tools/build/allyourbase.jam", "boost-build.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v1/allyourbase.jam", "Jamrules"),
-      std::pair<fs::path, fs::path>("tools/build/v1/allyourbase.jam", "project-root.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v1/allyourbase.jam", "boost-build.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "Jamrules"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "project-root.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "boost-build.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "Jamfile.v2"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "boostcpp.jam"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "bootstrap.bat"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "bootstrap.sh"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "Jamroot"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "INSTALL"),
-      std::pair<fs::path, fs::path>("tools/build/v2/boost-build.jam", "LICENSE_1_0.txt"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "Jamrules"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "project-root.jam"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "boost-build.jam"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "Jamfile.v2"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "boostcpp.jam"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "bootstrap.bat"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "bootstrap.sh"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "Jamroot"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "INSTALL"),
+      std::pair<fs::path, fs::path>("tools/build/boost-build.jam", "LICENSE_1_0.txt"),
       std::pair<fs::path, fs::path>("boost/preprocessor/iterate.hpp", "boost/preprocessor/iteration"),
       std::pair<fs::path, fs::path>("boost/preprocessor/slot/slot.hpp", "boost/preprocessor/slot/detail"),
       std::pair<fs::path, fs::path>("boost/function.hpp", "boost/function/detail"),
@@ -250,7 +252,6 @@ static const std::pair<fs::path, fs::path>
       std::pair<fs::path, fs::path>("boost/graph/distributed/detail/tag_allocator.hpp", "libs/graph_parallel"),
       std::pair<fs::path, fs::path>("boost/graph/distributed/mpi_process_group.hpp", "libs/graph_parallel"),
       std::pair<fs::path, fs::path>("boost/parameter/parameters.hpp", "boost/parameter/aux_/overloads.hpp"),
-      std::pair<fs::path, fs::path>("boost/chrono/chrono.hpp", "libs/chrono/src"),
    };
 
    for(unsigned int n = 0; n < (sizeof(specials)/sizeof(specials[0])); ++n)
