@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumListFactoryTest.cpp 6393 2014-06-17 20:02:26Z frenchwr $
+// $Id: SpectrumListFactoryTest.cpp 10650 2017-03-27 21:23:14Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -435,6 +435,186 @@ void testWrapTitleMaker()
     }
 }
 
+void intializeTinyWithThermoFilter(MSData& msd)
+{
+    examples::initializeTiny(msd);
+    // add some filter data on top of the tiny scan example.
+    SpectrumListPtr& sl = msd.run.spectrumListPtr;
+    for (size_t i=0; i<5; ++i)
+    {
+        SpectrumPtr spectrum = sl->spectrum(i);
+        ostringstream filterLine;
+        
+        if (i == 0) // scan=19
+            filterLine << "FTMS + p NSI SIM ms [595.0000-655.0000]";
+        else if (i == 1) // scan=20
+            filterLine << "FTMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@etd30.00 [100.0000-2000.0000]";
+        else if (i == 2) // scan=21
+            filterLine << "ITMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@cid30.00 [100.0000-2000.0000]";
+        else if (i == 3) // scan=22
+            filterLine << "FTMS + p NSI SIM ms [395.0000-1005.0000]";
+        else if (i == 4) // sample=1 period=1 cycle=23 experiment=1
+            filterLine << "ITMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@hcd30.00 [100.0000-2000.0000]";
+        spectrum->scanList.scans[0].set(MS_filter_string, filterLine.str());
+    }
+}
+
+void testWrapThermoScanFilter()
+{
+    MSData msd;
+    intializeTinyWithThermoFilter(msd);
+    auto originalSL = msd.run.spectrumListPtr;
+
+    {
+        SpectrumListFactory::wrap(msd, "thermoScanFilter contains include 395.0000-1005.0000");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert(sl->size() == 1);
+        unit_assert(sl->spectrumIdentity(0).id == "scan=22");
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "thermoScanFilter contains exclude 395.0000-1005.0000");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        cout << sl->size()<<endl;
+        unit_assert(sl->size() == 4);
+        unit_assert(sl->spectrumIdentity(0).id == "scan=19");
+        unit_assert(sl->spectrumIdentity(1).id == "scan=20");
+        unit_assert(sl->spectrumIdentity(2).id == "scan=21");
+        unit_assert(sl->spectrumIdentity(3).id == "sample=1 period=1 cycle=23 experiment=1");
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "thermoScanFilter exact include FTMS + p NSI SIM ms [395.0000-1005.0000]");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert(sl->size() == 1);
+        unit_assert(sl->spectrumIdentity(0).id == "scan=22");
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "thermoScanFilter exact exclude TMS + p NSI SIM ms [395.0000-1005.0000]");
+        // should not exclude anything
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert(sl->size() == 5);
+        unit_assert(sl->spectrumIdentity(0).id == "scan=19");
+        unit_assert(sl->spectrumIdentity(1).id == "scan=20");
+        unit_assert(sl->spectrumIdentity(2).id == "scan=21");
+        unit_assert(sl->spectrumIdentity(3).id == "scan=22");
+        unit_assert(sl->spectrumIdentity(4).id == "sample=1 period=1 cycle=23 experiment=1");
+    }
+}
+
+void testWrapPrecursorMzSet()
+{
+    MSData msd;
+    examples::initializeTiny(msd);
+    auto originalSL = msd.run.spectrumListPtr;
+
+    {
+        SpectrumListFactory::wrap(msd, "mzPrecursors [445]"); // default tolerance does not match to 445.34
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(0, sl->size());
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPrecursors [445] mzTol=1mz");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(1, sl->size());
+        unit_assert_operator_equal("scan=20", sl->spectrumIdentity(0).id);
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPrecursors [445] mzTol=1.0 mz"); // mzTol should still parse correctly with a space
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(1, sl->size());
+        unit_assert_operator_equal("scan=20", sl->spectrumIdentity(0).id);
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPrecursors [445.34] mode=exclude"); // only 1 MS2 left, but MS1s aren't excluded now
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(4, sl->size());
+        unit_assert_operator_equal("scan=19", sl->spectrumIdentity(0).id);
+        unit_assert_operator_equal("scan=21", sl->spectrumIdentity(1).id);
+        unit_assert_operator_equal("scan=22", sl->spectrumIdentity(2).id);
+        unit_assert_operator_equal("sample=1 period=1 cycle=23 experiment=1", sl->spectrumIdentity(3).id);
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPrecursors [0,445.34]"); // bring back the MS1s explicitly
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(4, sl->size());
+        unit_assert_operator_equal("scan=19", sl->spectrumIdentity(0).id);
+        unit_assert_operator_equal("scan=20", sl->spectrumIdentity(1).id);
+        unit_assert_operator_equal("scan=21", sl->spectrumIdentity(2).id);
+        unit_assert_operator_equal("sample=1 period=1 cycle=23 experiment=1", sl->spectrumIdentity(3).id);
+    }
+}
+
+void testWrapMZPresent()
+{
+    MSData msd;
+    examples::initializeTiny(msd);
+    auto originalSL = msd.run.spectrumListPtr;
+
+    // tiny spectra have simple m/z lists:
+    // s19: 0,1,2,...,15     15,14,13,...,0
+    // s20: 0,2,4,6,...,20   20,18,16,...,0
+    // s21: no data points
+    // s22: 0,2,4,6,...,20   20,18,16,...,0
+    // s23: 0,1,2,...,15     15,14,13,...,0
+
+    {
+        SpectrumListFactory::wrap(msd, "mzPresent [1.6] type=count threshold=100 orientation=most-intense");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(4, sl->size());
+        unit_assert_operator_equal("scan=19", sl->spectrumIdentity(0).id);
+        unit_assert_operator_equal("scan=20", sl->spectrumIdentity(1).id);;
+        unit_assert_operator_equal("scan=22", sl->spectrumIdentity(2).id);
+        unit_assert_operator_equal("sample=1 period=1 cycle=23 experiment=1", sl->spectrumIdentity(3).id);
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPresent [1.6] mzTol=1 ppm"); // mzTol should still parse correctly with a space; with this tight tolereance no spectra will match
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(0, sl->size());
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPresent [0]");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(4, sl->size());
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPresent [0] type=absolute threshold=17 orientation=most-intense mode=include");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(2, sl->size());
+        unit_assert_operator_equal("scan=20", sl->spectrumIdentity(0).id);
+        unit_assert_operator_equal("scan=22", sl->spectrumIdentity(1).id);
+    }
+
+    {
+        msd.run.spectrumListPtr = originalSL;
+        SpectrumListFactory::wrap(msd, "mzPresent [0] type=absolute threshold=17 orientation=most-intense mode=exclude");
+        SpectrumListPtr& sl = msd.run.spectrumListPtr;
+        unit_assert_operator_equal(3, sl->size());
+        unit_assert_operator_equal("scan=19", sl->spectrumIdentity(0).id);
+        unit_assert_operator_equal("scan=21", sl->spectrumIdentity(1).id);
+        unit_assert_operator_equal("sample=1 period=1 cycle=23 experiment=1", sl->spectrumIdentity(2).id);
+    }
+}
+
+
 void test()
 {
     testUsage(); 
@@ -449,6 +629,9 @@ void test()
     testWrapMassAnalyzer();
     testWrapPolarity();
     testWrapTitleMaker();
+    testWrapThermoScanFilter();
+    testWrapPrecursorMzSet();
+    testWrapMZPresent();
 }
 
 
