@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumList_FilterTest.cpp 6478 2014-07-08 20:01:38Z chambm $
+// $Id: SpectrumList_FilterTest.cpp 10650 2017-03-27 21:23:14Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -52,6 +52,7 @@ void printSpectrumList(const SpectrumList& sl, ostream& os)
            << "ms" << spectrum->cvParam(MS_ms_level).value << " "
            << "scanEvent:" << spectrum->scanList.scans[0].cvParam(MS_preset_scan_configuration).value << " "
            << "scanTime:" << spectrum->scanList.scans[0].cvParam(MS_scan_start_time).timeInSeconds() << " "
+           << "scanFilter:" << spectrum->scanList.scans[0].cvParam(MS_filter_string).value << " "
            << endl;
     }
 }
@@ -97,35 +98,54 @@ SpectrumListPtr createSpectrumList()
                 p->componentList.push_back(Component(MS_radial_ejection_linear_ion_trap, 0/*order*/));
         }
 
-        if (i%3 != 0)
-            spectrum->precursors.push_back(Precursor(500, 3));
+        // add thermo scan filter lines to the MS1 spectra
+        // MS1
+        if (i == 0 || i == 6) // narrow window MS1
+        {
+            spectrum->scanList.scans[0].set(MS_filter_string, "FTMS + p NSI SIM ms [595.0000-655.0000]");
+        }
+        else if (i == 3 || i == 9) // wide window MS1
+        {
+            spectrum->scanList.scans[0].set(MS_filter_string, "FTMS + p NSI SIM ms [395.0000-1005.0000]");
+        }
 
-        // add precursors and activation types to the MS2 spectra
+        if (i%3 != 0)
+            spectrum->precursors.push_back(Precursor((i+4)*100, 3));
+
+        // add precursors, activation types, and thermo scan filter lines to the MS2 spectra
+        ostringstream filterLine;
         if (i==1 || i ==5) // ETD
         {
             spectrum->precursors[0].activation.set(MS_electron_transfer_dissociation);
+            filterLine << "FTMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@etd30.00 [100.0000-2000.0000]";
         }
         else if (i==2) // CID
         {
             spectrum->precursors[0].activation.set(MS_collision_induced_dissociation);
+            filterLine << "ITMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@cid30.00 [100.0000-2000.0000]";
         }
         else if (i==4) // HCD
         {
             spectrum->precursors[0].activation.set(MS_HCD);
+            filterLine << "ITMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@hcd30.00 [100.0000-2000.0000]";
         }
         else if (i==8) // IRMPD
         {
             spectrum->precursors[0].activation.set(MS_IRMPD);
+            filterLine << "ITMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@irmpd30.00 [100.0000-2000.0000]";
         }
         else if (i==7) // ETD + SA
         {
             spectrum->precursors[0].activation.set(MS_electron_transfer_dissociation);
             spectrum->precursors[0].activation.set(MS_collision_induced_dissociation);
+            filterLine << "FTMS + c NSI Full ms2 " << (i + 4) * 100 << ".0000@irmpd30.00 [100.0000-2000.0000]";
         }
 
         spectrum->scanList.scans.push_back(Scan());
         spectrum->scanList.scans[0].set(MS_preset_scan_configuration, i%4);
         spectrum->scanList.scans[0].set(MS_scan_start_time, 420+i, UO_second);
+        if (i % 3 != 0)
+            spectrum->scanList.scans[0].set(MS_filter_string, filterLine.str());
         sl->spectra.push_back(spectrum);
     }
 
@@ -562,7 +582,7 @@ void testMassAnalyzerFilter(SpectrumListPtr sl)
     unit_assert(filter.spectrumIdentity(0).id == "scan=100");
 
     cvIDs.clear();
-	// msconvert mass analyzer filter ITMS option
+    // msconvert mass analyzer filter ITMS option
     cvIDs.insert(MS_ion_trap);
 
     SpectrumList_Filter filter1(sl, 
@@ -592,18 +612,18 @@ void testMZPresentFilter(SpectrumListPtr sl)
     double threshold = 10;
     IntegerSet msLevels(1, INT_MAX);
     ThresholdFilter tf(ThresholdFilter::ThresholdingBy_Count, threshold, ThresholdFilter::Orientation_MostIntense, msLevels);
-    SpectrumList_Filter filter(ms2filter, SpectrumList_FilterPredicate_MzPresent(mzt, mzSet, tf, false));
+    SpectrumList_Filter filter(ms2filter, SpectrumList_FilterPredicate_MzPresent(mzt, mzSet, tf, SpectrumList_Filter::Predicate::FilterMode_Include));
 
     if (os_)
     {
         printSpectrumList(filter, *os_);
         *os_ << endl;
     }
-    unit_assert(filter.size() == 4);
-    unit_assert(filter.spectrumIdentity(0).id == "scan=102");
-    unit_assert(filter.spectrumIdentity(1).id == "scan=104");
-    unit_assert(filter.spectrumIdentity(2).id == "scan=105");
-    unit_assert(filter.spectrumIdentity(3).id == "scan=107");
+    unit_assert_operator_equal(4, filter.size());
+    unit_assert_operator_equal("scan=102", filter.spectrumIdentity(0).id);
+    unit_assert_operator_equal("scan=104", filter.spectrumIdentity(1).id);
+    unit_assert_operator_equal("scan=105", filter.spectrumIdentity(2).id);
+    unit_assert_operator_equal("scan=107", filter.spectrumIdentity(3).id);
 
     // test mz present on MS level 1 (exclude test)
     SpectrumListPtr ms1filter(new SpectrumList_Filter(sl, SpectrumList_FilterPredicate_MSLevelSet(IntegerSet(1))));
@@ -613,17 +633,100 @@ void testMZPresentFilter(SpectrumListPtr sl)
     mzSet1.insert(300.0);
     double threshold1 = 5;
     ThresholdFilter tf1(ThresholdFilter::ThresholdingBy_Count, threshold1, ThresholdFilter::Orientation_MostIntense, msLevels);
-    SpectrumList_Filter filter1(ms1filter, SpectrumList_FilterPredicate_MzPresent(mzt1, mzSet1, tf1, true));
+    SpectrumList_Filter filter1(ms1filter, SpectrumList_FilterPredicate_MzPresent(mzt1, mzSet1, tf1, SpectrumList_Filter::Predicate::FilterMode_Exclude));
 
     if (os_)
     {
         printSpectrumList(filter1, *os_);
         *os_ << endl;
     }
-    unit_assert(filter1.size() == 3);
-    unit_assert(filter1.spectrumIdentity(0).id == "scan=100");
-    unit_assert(filter1.spectrumIdentity(1).id == "scan=106");
-    unit_assert(filter1.spectrumIdentity(2).id == "scan=109");
+    unit_assert_operator_equal(3, filter1.size());
+    unit_assert_operator_equal("scan=100", filter1.spectrumIdentity(0).id);
+    unit_assert_operator_equal("scan=106", filter1.spectrumIdentity(1).id);
+    unit_assert_operator_equal("scan=109", filter1.spectrumIdentity(2).id);
+}
+
+void testThermoFilterFilter(SpectrumListPtr sl)
+{
+    if (os_) *os_ << "testThermoFilterFilter:\n";
+
+    // test for query of "395.0000-1005.0000" using contains (include)
+    string queryString = "395.0000-1005.0000";
+    SpectrumList_Filter filter1(sl, SpectrumList_FilterPredicate_ThermoScanFilter(queryString, false, false));
+    if (os_)
+    {
+        *os_ << "Including all spectra that contain " << queryString << endl;
+        printSpectrumList(filter1, *os_);
+        *os_ << endl;
+    }
+    unit_assert(filter1.size() == 2);
+    unit_assert(filter1.spectrumIdentity(0).id == "scan=103");
+    unit_assert(filter1.spectrumIdentity(1).id == "scan=109");
+
+    // test for query of "395.0000-1005.0000" using contains (exclude)
+    SpectrumList_Filter filter2(sl, SpectrumList_FilterPredicate_ThermoScanFilter(queryString, false, true));
+    if (os_)
+    {
+        *os_ << "Excluding all spectra that contain " << queryString << endl;
+        printSpectrumList(filter2, *os_);
+        *os_ << endl;
+    }
+    unit_assert(filter2.size() == 8);
+    unit_assert(filter2.spectrumIdentity(0).id == "scan=100");
+    unit_assert(filter2.spectrumIdentity(1).id == "scan=101");
+    unit_assert(filter2.spectrumIdentity(2).id == "scan=102");
+    unit_assert(filter2.spectrumIdentity(3).id == "scan=104");
+    unit_assert(filter2.spectrumIdentity(4).id == "scan=105");
+    unit_assert(filter2.spectrumIdentity(5).id == "scan=106");
+    unit_assert(filter2.spectrumIdentity(6).id == "scan=107");
+    unit_assert(filter2.spectrumIdentity(7).id == "scan=108");
+
+    // test for query of "ms2" using contains (exclude)
+    queryString = "ms2";
+    SpectrumList_Filter filter3(sl, SpectrumList_FilterPredicate_ThermoScanFilter(queryString, false, true));
+    if (os_)
+    {
+        *os_ << "Excluding all spectra that contain " << queryString << endl;
+        printSpectrumList(filter3, *os_);
+        *os_ << endl;
+    }
+    unit_assert(filter3.size() == 4);
+    unit_assert(filter3.spectrumIdentity(0).id == "scan=100");
+    unit_assert(filter3.spectrumIdentity(1).id == "scan=103");
+    unit_assert(filter3.spectrumIdentity(2).id == "scan=106");
+    unit_assert(filter3.spectrumIdentity(3).id == "scan=109");
+
+    // test for exact query of "FTMS + p NSI SIM ms [395.0000-1005.0000]" (include)
+    queryString = "FTMS + p NSI SIM ms [395.0000-1005.0000]";
+    SpectrumList_Filter filter4(sl, SpectrumList_FilterPredicate_ThermoScanFilter(queryString, true, false));
+    if (os_)
+    {
+        *os_ << "Including all spectra that exactly match " << queryString << endl;
+        printSpectrumList(filter4, *os_);
+        *os_ << endl;
+    }
+    unit_assert(filter4.size() == 2);
+    unit_assert(filter4.spectrumIdentity(0).id == "scan=103");
+    unit_assert(filter4.spectrumIdentity(1).id == "scan=109");
+
+    // test for exact query of "FTMS + p NSI SIM ms [395.0000-1005.0000]" (exclude)
+    queryString = "FTMS + p NSI SIM ms [395.0000-1005.0000]";
+    SpectrumList_Filter filter5(sl, SpectrumList_FilterPredicate_ThermoScanFilter(queryString, true, true));
+    if (os_)
+    {
+        *os_ << "Excluding all spectra that exactly match " << queryString << endl;
+        printSpectrumList(filter5, *os_);
+        *os_ << endl;
+    }
+    unit_assert(filter5.size() == 8);
+    unit_assert(filter5.spectrumIdentity(0).id == "scan=100");
+    unit_assert(filter5.spectrumIdentity(1).id == "scan=101");
+    unit_assert(filter5.spectrumIdentity(2).id == "scan=102");
+    unit_assert(filter5.spectrumIdentity(3).id == "scan=104");
+    unit_assert(filter5.spectrumIdentity(4).id == "scan=105");
+    unit_assert(filter5.spectrumIdentity(5).id == "scan=106");
+    unit_assert(filter5.spectrumIdentity(6).id == "scan=107");
+    unit_assert(filter5.spectrumIdentity(7).id == "scan=108");
 }
 
 void test()
@@ -641,6 +744,7 @@ void test()
     testMS2Activation(sl);
     testMassAnalyzerFilter(sl);
     testMZPresentFilter(sl);
+    testThermoFilterFilter(sl);
 }
 
 
