@@ -1,5 +1,5 @@
 //
-// $Id: IOTest.cpp 4129 2012-11-20 00:05:37Z chambm $
+// $Id: IOTest.cpp 5759 2014-02-19 22:26:29Z chambm $
 //
 //
 // Original author: Robert Burke <robert.burke@proteowizard.org>
@@ -376,7 +376,7 @@ void testSearchModification()
     a.residues.push_back('Q');
     a.residues.push_back('E');
     a.set(UNIMOD_Gln__pyro_Glu);
-    a.specificityRules.cvid = MS_modification_specificity_N_term;
+    a.specificityRules.cvid = MS_modification_specificity_peptide_N_term;
 
     testObject(a);
 }
@@ -538,7 +538,7 @@ void testSpectraData()
 
     a.location = "here";
     a.externalFormatDocumentation.push_back("there");
-    a.fileFormat.cvid = MS_mzML_file;
+    a.fileFormat.cvid = MS_mzML_format;
     
     testObject(a);
 }
@@ -570,9 +570,9 @@ void testSourceFile()
     a.id = "id";
 
     a.location = "there";
-    a.fileFormat.cvid = MS_mzML_file;
+    a.fileFormat.cvid = MS_mzML_format;
     a.externalFormatDocumentation.push_back("somewhere else");
-    a.set(MS_Mascot_DAT_file);
+    a.set(MS_Mascot_DAT_format);
     
     testObject(a);
 }
