@@ -1,5 +1,5 @@
 //
-// $Id: IdentData.cpp 8868 2015-09-22 20:51:26Z kaipot $
+// $Id: IdentData.cpp 10246 2016-12-05 20:12:14Z chambm $
 //
 //
 // Original author: Robert Burke <robert.burke@proteowizard.org>
@@ -1023,7 +1023,12 @@ PWIZ_API_DECL proteome::DigestedPeptide digestedPeptide(const SpectrumIdentifica
         cleavageAgentRegexes = identdata::cleavageAgentRegexes(sip.enzymes);
 
         if (cleavageAgentRegexes.empty())
-            throw runtime_error("[identdata::digestedPeptide] unknown cleavage agent");
+        {
+            if (!sip.enzymes.enzymes.empty() && sip.enzymes.enzymes[0]->terminalSpecificity == Digestion::NonSpecific)
+                cleavageAgents.push_back(MS_unspecific_cleavage);
+            else
+                throw runtime_error("[identdata::digestedPeptide] unknown cleavage agent");
+        }
     }
 
     if (!hasValidFlankingSymbols(pe))
@@ -1197,7 +1202,7 @@ PWIZ_API_DECL string cleavageAgentRegex(const Enzyme& ez)
     {
         CVParam enzymeTerm = ez.enzymeName.cvParamChild(MS_cleavage_agent_name);
 
-        if (enzymeTerm.empty())
+        if (enzymeTerm.empty() && !ez.enzymeName.userParams.empty())
             enzymeTerm = CVParam(Digestion::getCleavageAgentByName(ez.enzymeName.userParams[0].name));
 
         try {return Digestion::getCleavageAgentRegex(enzymeTerm.cvid);} catch (exception&) {}
