@@ -1,5 +1,5 @@
 //
-// $Id: Serializer_pepXML_Test.cpp 5156 2013-11-14 23:07:56Z chambm $
+// $Id: Serializer_pepXML_Test.cpp 6943 2014-11-26 17:07:14Z chambm $
 //
 //
 // Original author: Matt Chambers <matt.chambers .@. vanderbilt.edu>
@@ -32,6 +32,7 @@
 #include "boost/range/adaptor/transformed.hpp"
 #include "boost/range/algorithm/max_element.hpp"
 #include "boost/range/algorithm/min_element.hpp"
+#include "boost/range/algorithm_ext/erase.hpp"
 #include <cstring>
 
 
@@ -54,6 +55,15 @@ struct EnzymePtr_missedCleavages
     int operator()(const EnzymePtr& x) const {return x->missedCleavages;}
 };
 
+struct UserParamNameIs
+{
+    UserParamNameIs(const string& name) : name_(name) {}
+
+    bool operator() (const UserParam& up) const { return up.name == name_; }
+
+    string name_;
+};
+
 void stripUnmappedMetadata(IdentData& mzid)
 {
     mzid.bibliographicReference.clear();
@@ -180,6 +190,9 @@ void testSerializeReally(IdentData& mzid, const Serializer_pepXML::Config& confi
 
     References::resolve(mzid2);
 
+    // remove DecoyPrefix userParam that is redundant with the decoy DB prefix cvParam
+    boost::range::remove_erase_if(mzid2.analysisProtocolCollection.spectrumIdentificationProtocol[0]->additionalSearchParams.userParams, UserParamNameIs("DecoyPrefix"));
+
     Diff<IdentData, DiffConfig> diff(mzid, mzid2);
     if (os_ && diff) *os_ << diff << endl; 
     unit_assert(!diff);
