@@ -1,5 +1,5 @@
 //
-// $Id: examples.cpp 6943 2014-11-26 17:07:14Z chambm $ 
+// $Id: examples.cpp 9934 2016-08-02 17:48:03Z chambm $ 
 //
 //
 // Original author: Robert Burke <robert.burke@proteowizard.org>
@@ -236,7 +236,7 @@ PWIZ_API_DECL void initializeBasicSpectrumIdentification(IdentData& mzid)
     sip->additionalSearchParams.set(MS_param__a_ion);
     sip->additionalSearchParams.set(MS_param__b_ion);
     sip->additionalSearchParams.set(MS_param__y_ion);
-    sip->additionalSearchParams.set(MS_NH3_neutral_loss);
+    sip->additionalSearchParams.set(MS_NH3_neutral_loss_OBSOLETE);
     sip->additionalSearchParams.userParams.push_back(UserParam("INSTRUMENT", "Default"));
     sip->additionalSearchParams.userParams.push_back(UserParam("MASS", "Monoisotopic"));
     sip->additionalSearchParams.userParams.push_back(UserParam("PFA", "1"));
