@@ -1,5 +1,5 @@
 //
-// $Id: IOTest.cpp 4129 2012-11-20 00:05:37Z chambm $
+// $Id: IOTest.cpp 6478 2014-07-08 20:01:38Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -217,7 +217,7 @@ void testFileDescription()
     a.fileContent.cvParams.push_back(MS_MSn_spectrum);
     
     SourceFilePtr sf(new SourceFile("1", "tiny1.RAW", "file://F:/data/Exp01"));
-    sf->cvParams.push_back(MS_Thermo_RAW_file);
+    sf->cvParams.push_back(MS_Thermo_RAW_format);
     sf->cvParams.push_back(MS_SHA_1);
     a.sourceFilePtrs.push_back(sf);
 
@@ -965,7 +965,7 @@ void initializeTestData(MSData& msd)
     sfp->id = "1";
     sfp->name = "tiny1.RAW";
     sfp->location = "file://F:/data/Exp01";
-    sfp->cvParams.push_back(MS_Thermo_RAW_file);
+    sfp->cvParams.push_back(MS_Thermo_RAW_format);
     sfp->cvParams.push_back(CVParam(MS_SHA_1,"71be39fb2700ab2f3c8b2234b91274968b6899b1"));
     msd.fileDescription.sourceFilePtrs.push_back(sfp);
 
@@ -985,13 +985,11 @@ void initializeTestData(MSData& msd)
     ParamGroupPtr pg1(new ParamGroup);
     pg1->id = "CommonMS1SpectrumParams";
     pg1->cvParams.push_back(MS_positive_scan);
-    pg1->cvParams.push_back(MS_full_scan);
     msd.paramGroupPtrs.push_back(pg1);
 
     ParamGroupPtr pg2(new ParamGroup);
     pg2->id = "CommonMS2SpectrumParams";
     pg2->cvParams.push_back(MS_positive_scan);
-    pg2->cvParams.push_back(MS_full_scan);
     msd.paramGroupPtrs.push_back(pg2);
 
     // sampleList
