@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumListBase.hpp 6385 2014-06-12 22:56:04Z chambm $
+// $Id: SpectrumListBase.hpp 8725 2015-08-04 15:49:57Z pcbrefugee $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -26,6 +26,7 @@
 
 
 #include "pwiz/data/msdata/MSData.hpp"
+#include "pwiz/utility/misc/IntegerSet.hpp"
 #include <boost/functional/hash.hpp>
 #include <stdexcept>
 #include <iostream>
@@ -39,6 +40,7 @@ namespace msdata {
 class PWIZ_API_DECL SpectrumListBase : public SpectrumList
 {
     public:
+    SpectrumListBase() : MSLevelsNone() {};
 
     /// implementation of SpectrumList
     virtual const boost::shared_ptr<const DataProcessing> dataProcessingPtr() const {return dp_;}
@@ -60,6 +62,9 @@ class PWIZ_API_DECL SpectrumListBase : public SpectrumList
 
     DataProcessingPtr dp_;
 
+    // Useful for avoiding repeated ctor when you just want an empty set
+    const pwiz::util::IntegerSet MSLevelsNone;
+
     private:
 
     mutable std::set<size_t> warn_msg_hashes; // for warn_once use
