@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumList_MSn.cpp 7364 2015-04-08 10:50:54Z kaipot $
+// $Id: SpectrumList_MSn.cpp 10158 2016-11-02 22:29:05Z kaipot $
 //
 //
 // Original author: Barbara Frewen <frewen@u.washington.edu>
@@ -313,7 +313,7 @@ class SpectrumList_MSnImpl : public SpectrumList_MSn
             double z_precursor_mz = calculateMassOverCharge(
                 lexical_cast<double>(lineStr.substr(last_space_pos+1, last_num_pos-last_space_pos)), charge, 1);
             stringstream ss;
-            ss << charge << ' ' << z_precursor_mz;
+            ss << charge << ' ' << std::fixed << std::setprecision(4) << z_precursor_mz;
             // Store Z line information in UserParams, in the format "<charge> <m/z calculated from Z line mass>"
             spectrum.userParams.push_back(UserParam("ms2 file charge state", ss.str()));
         }
