@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumWorkerThreads.cpp 7230 2015-02-26 17:23:51Z chambm $
+// $Id: SpectrumWorkerThreads.cpp 10352 2017-01-11 20:59:11Z chambm $
 //
 //
 // Original author: William French <william.r.french .@. vanderbilt.edu>
@@ -55,7 +55,27 @@ class SpectrumWorkerThreads::Impl
         }
 
         bool isBruker = icPtr.get() && icPtr->hasCVParamChild(MS_Bruker_Daltonics_instrument_model);
-        useThreads_ = !isBruker; // Bruker library is not thread-friendly
+
+        bool isDemultiplexed = false;
+        const boost::shared_ptr<const DataProcessing> dp = sl.dataProcessingPtr();
+        if (dp)
+        {
+            BOOST_FOREACH(const ProcessingMethod& pm, dp->processingMethods)
+            {
+                if (!pm.hasCVParam(MS_data_processing)) continue;
+                BOOST_FOREACH(const UserParam& up, pm.userParams)
+                {
+                    if (up.name.find("Demultiplexing") != std::string::npos)
+                    {
+                        isDemultiplexed = true;
+                        break;
+                    }
+                }
+                if (isDemultiplexed) break;
+            }
+        }
+
+        useThreads_ = !(isBruker || isDemultiplexed); // Bruker library is not thread-friendly
 
         if (sl.size() > 0 && useThreads_)
         {
