@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumList_Agilent.hpp 6585 2014-08-07 22:49:28Z chambm $
+// $Id: SpectrumList_Agilent.hpp 10494 2017-02-21 16:53:20Z pcbrefugee $
 //
 //
 // Original author: Matt Chambers <matt.chambers .@. vanderbilt.edu>
@@ -62,6 +62,10 @@ class PWIZ_API_DECL SpectrumList_Agilent : public SpectrumListBase
 
     virtual pwiz::analysis::Spectrum3DPtr spectrum3d(double scanStartTime, const boost::icl::interval_set<double>& driftTimeRanges) const;
 
+    virtual bool canConvertDriftTimeAndCCS() const;
+    virtual double driftTimeToCCS(double driftTime, double mz, int charge) const;
+    virtual double ccsToDriftTime(double ccs, double mz, int charge) const;
+
 #ifdef PWIZ_READER_AGILENT
     SpectrumList_Agilent(const MSData& msd, MassHunterDataPtr rawfile, const Reader::Config& config);
 
