@@ -1,5 +1,5 @@
 //
-// $Id: SpectrumList_Bruker.cpp 7127 2015-01-27 18:41:39Z pcbrefugee $
+// $Id: SpectrumList_Bruker.cpp 9935 2016-08-02 18:10:51Z chambm $
 //
 //
 // Original author: Matt Chambers <matt.chambers .@. vanderbilt.edu>
@@ -338,7 +338,7 @@ PWIZ_API_DECL SpectrumPtr SpectrumList_Bruker::spectrum(size_t index, DetailLeve
             {
                 result->set(MS_centroid_spectrum); // Declare this as centroided data even if scan is empty
                 spectrum->getLineData(mzArray, intensityArray);
-                if (mzArray.size() > 0)
+                if (mzArray.size() > 0 && msLevelsToCentroid.contains(msLevel))
                 {
                     result->set(MS_profile_spectrum); // let SpectrumList_PeakPicker know this was probably also a profile spectrum, but doesn't need conversion (actually checking for profile data is crazy slow)
                 }
