@@ -1,5 +1,5 @@
 //
-// $Id: ExtendedReaderList.cpp 5941 2014-03-20 17:40:27Z chambm $
+// $Id: ExtendedReaderList.cpp 6770 2014-10-09 20:35:21Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -30,6 +30,7 @@
 #include "Bruker/Reader_Bruker.hpp"
 #include "Shimadzu/Reader_Shimadzu.hpp"
 #include "Thermo/Reader_Thermo.hpp"
+#include "UIMF/Reader_UIMF.hpp"
 #include "Waters/Reader_Waters.hpp"
 #include "pwiz/utility/misc/Std.hpp"
 
@@ -46,6 +47,7 @@ PWIZ_API_DECL ExtendedReaderList::ExtendedReaderList()
     push_back(ReaderPtr(new Reader_Bruker));
     push_back(ReaderPtr(new Reader_Shimadzu));
     push_back(ReaderPtr(new Reader_Thermo));
+    push_back(ReaderPtr(new Reader_UIMF));
     push_back(ReaderPtr(new Reader_Waters));
 }
 
