@@ -1,5 +1,5 @@
 //
-// $Id: ChromatogramList_Shimadzu.cpp 8738 2015-08-06 22:19:25Z kaipot $
+// $Id: ChromatogramList_Shimadzu.cpp 9490 2016-03-22 22:20:36Z pcbrefugee $
 //
 //
 // Original author: Matt Chambers <matt.chambers .@. vanderbilt.edu>
@@ -159,7 +159,8 @@ PWIZ_API_DECL void ChromatogramList_Shimadzu::createIndex() const
         IndexEntry& ci = index_.back();
         ci.index = index_.size()-1;
         ci.transition = transition;
-        ci.id = (format("SRM SIC Q1=%.10g Q3=%.10g Channel=%d Event=%d Segment=%d CE=%.10g"/* start=%.10g end=%.10g"*/)
+        ci.id = (format("%sSRM SIC Q1=%.10g Q3=%.10g Channel=%d Event=%d Segment=%d CE=%.10g"/* start=%.10g end=%.10g"*/)
+                    % polarityStringForFilter((transition.polarity == 1) ? MS_negative_scan : MS_positive_scan)
                     % transition.Q1
                     % transition.Q3
                     % transition.channel
