@@ -1,5 +1,5 @@
 //
-// $Id: Reader_Thermo_Detail.cpp 7303 2015-03-13 20:19:40Z chambm $
+// $Id: Reader_Thermo_Detail.cpp 10422 2017-02-02 19:51:54Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -104,6 +104,8 @@ PWIZ_API_DECL CVID translateAsInstrumentModel(InstrumentModelType instrumentMode
         case InstrumentModelType_Accela_PDA:                return MS_Accela_PDA;
         case InstrumentModelType_Orbitrap_Fusion:           return MS_Orbitrap_Fusion;
         case InstrumentModelType_Orbitrap_Fusion_ETD:       return MS_Orbitrap_Fusion_ETD;
+        case InstrumentModelType_TSQ_Quantiva:              return MS_TSQ_Quantiva;
+        case InstrumentModelType_TSQ_Endura:                return MS_TSQ_Endura;
 
         default:
             throw std::runtime_error("[Reader_Thermo::translateAsInstrumentModel] Enumerated instrument model " + lexical_cast<string>(instrumentModelType) + " has no CV term mapping!");
@@ -253,6 +255,8 @@ vector<InstrumentConfiguration> createInstrumentConfigurations(const Component&
         case InstrumentModelType_TSQ_Vantage_Standard:
         case InstrumentModelType_TSQ_Vantage_EMR:
         case InstrumentModelType_GC_Quantum:
+        case InstrumentModelType_TSQ_Quantiva:
+        case InstrumentModelType_TSQ_Endura:
             configurations.push_back(InstrumentConfiguration());
             configurations.back().componentList.push_back(commonSource);
             configurations.back().componentList.push_back(Component(MS_quadrupole, 2));
