@@ -1,5 +1,5 @@
 //
-// $Id: SAXParser.cpp 6909 2014-11-19 17:18:29Z chambm $
+// $Id: SAXParser.cpp 9576 2016-04-18 19:54:12Z chambm $
 //
 //
 // Original author: Darren Kessner <darren@proteowizard.org>
@@ -551,7 +551,8 @@ PWIZ_API_DECL void parse(istream& is, Handler& handler)
 
 string xml_root_element(const string& fileheader)
 {
-    const static bxp::sregex e = bxp::sregex::compile("<\\?xml.*?>.*?<([^?!]\\S+?)[\\s>]");
+    // TODO: make this static again when we switch to a proper C++11 compiler (e.g. VC++ 2015)
+    const /*static*/ bxp::sregex e = bxp::sregex::compile("<\\?xml.*?>.*?<([^?!]\\S+?)[\\s>]");
 
     // convert Unicode to ASCII
     string asciiheader;
