@@ -1,5 +1,5 @@
 //
-// $Id: idconvert.cpp 4010 2012-10-17 20:22:16Z chambm $
+// $Id: idconvert.cpp 6865 2014-10-31 21:47:12Z chambm $
 //
 //
 // Original author: Matt Chambers <matt.chambers .@. vanderbilt.edu>
@@ -50,13 +50,30 @@ struct Config
     :   outputPath("."), verbose(false)//, merge(false)
     {}
 
-    string outputFilename(const string& inputFilename, const IdentData& inputIdentData) const;
+    string outputFilename(const string& inputFilename, const IdentData& inputIdentData, bool multipleOutputs) const;
 };
 
 
-string Config::outputFilename(const string& filename, const IdentData& idd) const
+string Config::outputFilename(const string& filename, const IdentData& idd, bool multipleOutputs) const
 {
-    bfs::path fullPath = bfs::path(outputPath) / (bfs::basename(filename) + extension);
+    if (idd.dataCollection.inputs.spectraData.empty())
+        throw runtime_error("[Config::outputFilename] no spectraData elements");
+
+    string sourceName;
+    if (multipleOutputs)
+        sourceName = idd.id;
+    if (sourceName.empty())
+        sourceName = bfs::basename(idd.dataCollection.inputs.spectraData[0]->name);
+    if (sourceName.empty())
+        sourceName = bfs::basename(filename);
+    
+    // this list is for Windows; it's a superset of the POSIX list
+    string illegalFilename = "\\/*:?<>|\"";
+    BOOST_FOREACH(char& c, sourceName)
+        if (illegalFilename.find(c) != string::npos)
+            c = '_';
+
+    bfs::path fullPath = bfs::path(outputPath) / (sourceName + extension);
     return fullPath.string(); 
 }
 
@@ -423,6 +440,7 @@ void processFile(const string& filename, const Config& config, const ReaderList&
     vector<IdentDataPtr> iddList;
     Reader::Config readerConfig;
     readerConfig.iterationListenerRegistry = pILR;
+    readerConfig.ignoreProteinDetectionList = config.writeConfig.format == IdentDataFile::Format_pepXML;
     readers.read(filename, iddList, readerConfig);
 
     for (size_t i=0; i < iddList.size(); ++i)
@@ -436,7 +454,7 @@ void processFile(const string& filename, const Config& config, const ReaderList&
                 addContactInfo(msd, config.contactFilename);*/
 
             // write out the new data file
-            string outputFilename = config.outputFilename(filename, idd);
+            string outputFilename = config.outputFilename(filename, idd, iddList.size() > 1);
             cout << "writing output file: " << outputFilename << endl;
 
             if (config.outputPath == "-")
